<template>
  <div class="relative block bg-[#ebe5ff] p-6 overflow-hidden" style="height: calc(100% - 10rem)">
    <button @click="closeButton()"
            class="absolute right-4 top-4 w-9 h-9 bg-scheme-primary transition duration-300 hover:bg-[#916bfd] p-3 rounded-full">
      <svg class="w-15 h-15" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" version="1.1"
           viewBox="0 0 256 256" xml:space="preserve">
            <g style="stroke: none; stroke-width: 0; stroke-dasharray: none; stroke-linecap: butt; stroke-linejoin: miter; stroke-miterlimit: 10; fill: none; fill-rule: nonzero; opacity: 1;"
               transform="translate(1.4065934065934016 1.4065934065934016) scale(2.81 2.81)">
                <path
                    d="M 6 90 c -1.536 0 -3.071 -0.586 -4.243 -1.758 c -2.343 -2.343 -2.343 -6.142 0 -8.484 l 78 -78 c 2.342 -2.343 6.143 -2.343 8.484 0 c 2.344 2.343 2.344 6.142 0 8.485 l -78 78 C 9.071 89.414 7.536 90 6 90 z"
                    style="stroke: none; stroke-width: 1; stroke-dasharray: none; stroke-linecap: butt; stroke-linejoin: miter; stroke-miterlimit: 10; fill: white; fill-rule: nonzero; opacity: 1;"
                    transform=" matrix(1 0 0 1 0 0) " stroke-linecap="round"/>
              <path
                  d="M 84 90 c -1.535 0 -3.071 -0.586 -4.242 -1.758 l -78 -78 c -2.343 -2.343 -2.343 -6.142 0 -8.485 c 2.343 -2.343 6.143 -2.343 8.485 0 l 78 78 c 2.344 2.343 2.344 6.142 0 8.484 C 87.071 89.414 85.535 90 84 90 z"
                  style="stroke: none; stroke-width: 1; stroke-dasharray: none; stroke-linecap: butt; stroke-linejoin: miter; stroke-miterlimit: 10; fill: white; fill-rule: nonzero; opacity: 1;"
                  transform=" matrix(1 0 0 1 0 0) " stroke-linecap="round"/>
            </g>
            </svg>
    </button>
    <div class="block relative h-full m-auto w-auto max-w-2xl">
      <div class="relative flex items-center justify-center h-full p-6 overflow-hidden hover:bg-black rounded-lg hover:bg-opacity-5 transition duration-300">
        <img crossorigin="anonymous" v-if="chat.typeMedia == 'image'" class="object-cover max-h-full w-auto"
             :src="helpers.generateImage(chat.mediaURL)"/>

        <template v-if="chat.typeMedia == 'video'">
          <video id="idVideo" @pause="onPaused()" class="object-fill h-full w-auto">
            <source :src="chat.mediaURL">
            Your browser does not support the video tag.
          </video>
          <button type="button" @click="playVideo()" id="playVideo" style="box-shadow: 0px 4px 4px rgba(0, 0, 0, 0.25);"
                  class="overflow-hidden w-12 h-12 bg-white transition duration-300 hover:bg-opacity-80 p-3 rounded-full group">
            <svg class="w-full h-full" style="padding-left: 0.3em;" viewBox="0 0 22 26" fill="none"
                 xmlns="http://www.w3.org/2000/svg">
              <path
                  d="M21 11.268C22.3333 12.0378 22.3333 13.9622 21 14.7321L3 25.1244C1.66667 25.8942 3.33085e-07 24.9319 3.14725e-07 23.3923L6.68711e-08 2.60769C4.85115e-08 1.06809 1.66667 0.105845 3 0.875645L21 11.268Z"
                  fill="#7646FC"/>
            </svg>
          </button>
        </template>
      </div>
    </div>
  </div>

  <div class="relative block bg-white overflow-hidden h-20 w-full border-t border-gray-200">
    <div
        :class="`${isExpired ? 'disabled cursor-not-allowed' : ''}  relative flex justify-between items-center align-middle h-full pr-8 gap-3`">
        <div class="flex gap-4 items-center w-full h-full py-3 relative px-3">
            <div class="flex items-center gap-2 overflow-hidden relative bg-gray-200 w-full h-full rounded-lg">
                <a-textarea
                        v-model:value="messageForm"
                        @keydown.enter.exact.prevent="onKeyupMessage"
                        @keydown.enter.shift.exact.prevent="onKeydownMessage"
                        :bordered="false"
                        id="input-sendMessage"
                        class="w-full !items-center !py-3 !border-4 !items-center !flex !relative  !border-0 !resize-none !leading-none px-3 !h-full !min-h-full"
                        placeholder="Ketik Pesan"
                        auto-size
                />
            </div>
            <button @click.prevent="sendMedia()"
                    class="relative overflow-hidden flex items-center justify-center text-center w-12 h-12 bg-scheme-primary transition duration-300 hover:bg-opacity-80 p-3 rounded-full group"
            >
                <!--            <IcLoading v-if="isSendMessage"/>-->
                <IcLoading v-if="isLoading"/>
                <IcPaperPlane v-else/>
            </button>
            <!--                <button-->
            <!--                        @click="sendDocument"-->
            <!--                        class="right-8 absolute overflow-hidden w-12 h-12 bg-scheme-primary transition duration-300 hover:bg-opacity-80 p-3 rounded-full group"-->
            <!--                        id="btn-sendMessage">-->


            <!--                </button>-->
        </div>
<!--      <div class="flex gap-4 items-center">-->

<!--        <button-->
<!--            @click="sendMedia"-->
<!--            class="right-8 absolute overflow-hidden w-12 h-12 bg-scheme-primary transition duration-300 hover:bg-opacity-80 p-3 rounded-full group"-->
<!--            id="btn-sendMessage">-->

<!--          <IcLoading v-if="isLoading"/>-->
<!--          <IcPaperPlane v-else/>-->
<!--        </button>-->
<!--      </div>-->
    </div>
  </div>
</template>
<script setup lang="ts">

import {useChatListStore} from "../../../stores/chat_list"
import {useGeneralStore} from "../../../stores/general";
import IcLoading from "../../Icon/IcLoading.vue"
import IcPaperPlane from "../../Icon/IcPaperPlane.vue"

import {ref} from "vue"
import helpers from "../../../utils/helpers";
interface Props {
  chatId: number
}

let prop =  withDefaults(defineProps<Props>(), {
  chatId: null
})
const messageForm = ref("")
const isExpired = ref()
const chat = useChatListStore()
const textmessage = ref()
const isLoading = ref(false)

const general = useGeneralStore()

const emit = defineEmits([
    'mediaData', 'mediaPlaceholder'])


const onKeyupMessage = async (event) => {
    if (messageForm.value.length > 0) {
        // await sendMessage()
    }
}

const onKeydownMessage = (event) => {
    messageForm.value = messageForm.value + "\n"
}
function closeButton() {
  chat.toggleMedia = !chat.toggleMedia
  const formMedia = document.getElementById('fileMedia') as HTMLFormElement
  formMedia.value = ''
}

function playVideo() {
  const idVideo = document.getElementById('idVideo') as HTMLFormElement
  const playVideo = document.getElementById('playVideo') as HTMLFormElement
  idVideo.play()
  idVideo.setAttribute("controls", "controls")
  playVideo.style.display = "none"
}

function onPaused() {
  const idVideo = document.getElementById('idVideo') as HTMLFormElement
  const playVideo = document.getElementById('playVideo') as HTMLFormElement
  idVideo.removeAttribute("controls")
  playVideo.style.display = "block"
}

const sendMedia = async () => {
  isLoading.value = true

  const formMedia = document.getElementById('fileMedia') as HTMLFormElement

  const payload = new FormData();

  payload.append("to", chat.detail.customer.phone);
  payload.append("file", formMedia.files[0]);
  payload.append("type", chat.typeMedia);
    if (chat.replyChat.isReplying) {
        payload.append("reply_to_chat_id", chat.replyChat.chatId);
    }

  const beforeSendMessageData = {
    "id": `666${prop.chatId}`,
    "tempid": parseInt(`666${prop.chatId}`),
    "type": "IMAGE",
    "chat_from": "SELLER",
    "from_user_id": 0,
    "chat_to": "CUSTOMER",
    "send_loading": true,
    "is_temporary": true,
    "to_user_id": 0,
    "message": null,
    "message_time": helpers.datenow(),
    "user_vendor_id": 0,
    "message_time_string": "1 second",
    "object": {
      "list": [],
      "button": [],
      "product_list": null,
      "location": null,
      "order": null,
      "image": {
        "image_url": URL.createObjectURL(formMedia.files[0])
      },
      "video": null,
      "document": null
    },
    "user_vendor":null,
  }
  // emit('mediaData', {
  //   isTemporary: true,
  //   data: beforeSendMessageData
  // })

  let type_chat = general.chatTab
  if(general.chatTab === 'instagram'){
    type_chat = 'instagram'

    if(chat.selectedChatType === 'instagram'){
      payload.append("platform", 'instagram')
    }
    
    if(chat.selectedChatType === 'facebook'){
      payload.append("platform", 'page')
    }
  }

  await chat.sendMediaMessage(chat.detail.customer.user_chat_id, payload, type_chat).then(async (resp) => {
    if ("code" in resp && resp.code == 200) {
      
      await chat.closeReplyToChat()
      
      const tempId = {"tempid": parseInt(`666${prop.chatId}`)};

       emit('mediaData', resp.data)
      // console.log("BERHASIL HARUSNYA DISINI", Object.assign({}, resp.data, tempId))
      helpers.scrollToBottomChat()
      // messageForm.value = null
    } else {
      // alert(resp)
    }
  })

  isLoading.value = false
  closeButton()
  // closeButton()
}

</script>

<style scoped>
#playVideo {
  position: absolute;
  top: 50%;
  left: 50%;
  transform: translate(-50%, -50%);
  -webkit-transform: translate(-50%, -50%);
}
</style>